==> scummvm_2.8.0%2Bdfsg.orig.tar.xz: scummvm-2.8.0/backends/cloud/cloudicon_disabled_data.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

// This is a PNG file dumped into array.
// $ recode data..d1 <dists/cloudicon_disabled.png >cloudicon_disabled_data.h
// The tool is from https://github.com/pinard/Recode

byte cloudicon_disabled_data[] = {
	137,  80,  78,  71,  13,  10,  26,  10,   0,   0,   0,  13,  73,  72,  68,
	82,   0,   0,   0,  32,   0,   0,   0,  32,   8,   6,   0,   0,   0, 115,
	122, 122, 244,   0,   0,   0,   4, 115,  66,  73,  84,   8,   8,   8,   8,
	124,   8, 100, 136,   0,   0,   0,   9, 112,  72,  89, 115,   0,   0,  11,
	18,   0,   0,  11,  18,   1, 210, 221, 126, 252,   0,   0,   0,  22, 116,
	69,  88, 116,  67, 114, 101,  97, 116, 105, 111, 110,  32,  84, 105, 109,
	101,   0,  48,  54,  47,  48,  51,  47,  49,  54, 159, 192, 233, 192,   0,
	0,   0,  28, 116,  69,  88, 116,  83, 111, 102, 116, 119,  97, 114, 101,
	0,  65, 100, 111,  98, 101,  32,  70, 105, 114, 101, 119, 111, 114, 107,
	115,  32,  67,  83,  54, 232, 188, 178, 140,   0,   0,   4, 139,  73,  68,
	65,  84,  88, 133, 197, 215,  91, 168,  86,  69,  20,   7, 240, 223, 254,
	244, 120, 236, 120,  57,  26,  94,  10,  31,  34,  35,  11,  36, 203,  74,
	212, 160, 204, 212, 110, 166, 248, 208, 205, 172, 151, 144, 136, 158,  82,
	80, 168,  32, 233, 165, 160,  32, 130, 236, 165,  34, 204,  74,  18,  52,
	36, 169, 232,  34,  24, 221, 243, 218, 133,  74,  77, 195,  44, 200,  91,
	122, 188, 156, 172, 102, 159, 221, 195, 204, 246, 219, 126, 231, 226,  17,
	138,  22,  12, 123, 246, 236, 153, 245,  95, 107, 205, 127, 205, 172, 157,
	21, 254,  95, 233,  27, 122,  63, 183,   5, 179,  48,  13,  87,  98,  52,
	6, 167, 111,  71, 176,  11,  27, 177,  14, 107, 209, 222,  27, 165, 217,
	137, 211, 207,  25, 137, 197, 152, 143,  65, 189, 209, 137, 163, 120,   1,
	79,  98, 111, 143, 147, 143, 247, 172, 108,  62, 158, 194,  16,  20, 169,
	105, 232, 151,  82, 171,  24,  80,  74,  27,  22, 225, 197, 110,  13, 104,
	235, 122, 188,  31,  94, 194,  93,  21, 192,  14,  49, 172, 223, 226, 109,
	124, 130,  29, 232, 131,  49, 184,  22,  55, 166, 126,  75, 131,  65, 175,
	225,  94, 252, 213, 201, 128, 131,  93, 131, 191, 137,  27,  42, 192, 199,
	241,   6, 158, 192, 246, 238, 188,  73,  50,   6, 143,  98,  78,  50, 164,
	140, 200, 123,  34, 135,  78,  49,  34, 219, 215,  89, 193, 171, 152, 151,
	192,   3, 246, 224,   1, 188, 123,  26, 224, 170,  92, 134, 143,  49, 160,
	50,  86,  96,   5, 238, 174,  78, 108, 204, 130, 249,  98, 216,  75, 240,
	109, 184,  13,  63, 156,   1, 248,  68,  44,  21, 189,  47, 165,  67, 140,
	196,  60, 172,  87, 225,  68, 182, 167,  62, 105, 100,   2, 106,  77,  11,
	118, 139, 123, 186, 163,  59, 164,  53,  76,  16, 195, 125,  29, 250,  15,
	227, 167,  73,  12, 237,  27,  73,  91,  75, 142,  28,  21, 185,  51,  60,
	141, 181, 225,  98,  41,  59, 106,  33, 185,  26,  88,  28, 104,  77, 253,
	163, 129, 251,   3,  59,  42, 223,  79, 105, 171, 184,  53, 240,  73, 224,
	150,  64, 203,  32, 106,  99, 185, 160, 224, 236,  16, 245, 118,   4,  54,
	5, 166,   4,  22,   6, 218, 211, 218, 214, 132,  37,  32,  75, 238, 181,
	224,  55,  12,  76, 222, 191, 140, 251, 144,  39,  79, 135,  98,   1, 198,
	98,  11, 150, 227, 251,  50, 204,  67, 113, 121,  90, 156,  57, 185, 127,
	135, 154, 184,   9,  95, 160,   9,  43,  49,  59,  69, 225,  24, 206,  65,
	123, 150,  54, 247,  14, 188, 158, 214,  30,  23,  79, 186, 109,   9, 252,
	44, 124, 142, 113, 149, 232, 127, 134, 201, 196,  88,  79,  66, 115,   5,
	252,  24, 182, 114, 224,  32,  35, 230, 212, 207, 139,  75, 241, 169, 168,
	47, 195, 157,  88,  89, 110, 193, 180,  64, 145, 250, 223,   5, 182,  87,
	194, 125, 123,  96,  92, 195,  22,  76,  14, 201, 227, 177, 226,  65, 144,
	227, 111,  28, 198, 151, 113, 131, 135,   5,  46, 169, 172, 249,  38, 176,
	187, 242,  62,  35, 160, 150, 199, 197,  19, 114, 178, 156,  34, 231, 173,
	244, 180, 154, 115, 115, 166, 166,  57, 167, 180, 193,  34,   3,   7, 165,
	61,  11, 137, 105,  27, 112, 160,  62, 111, 235, 106,  22, 166, 126,  71,
	206,  59, 165, 238, 156,  43, 114, 100, 155,  98, 120, 218, 146, 206,   2,
	83, 241, 225,  26, 134, 165, 253,  27, 173,  65, 134, 138, 137, 222, 154,
	222, 139, 228, 249,  87, 233, 217, 133,  76, 159,  19,  47, 169,  89, 226,
	129, 214,  71, 188, 192, 134, 148, 231,  64, 121, 171,  21, 248,  85, 244,
	232, 177,  30, 192,  59,  90,  82,   6, 193,   9, 108, 234,  30,  28,  30,
	9, 209, 128,  74, 214,  71, 204, 190, 121, 231, 201,   5, 228, 220, 218,
	248,  97, 136, 200, 246, 102, 106,  29, 234,  73, 190,   5, 135, 186,   7,
	135, 201,   9, 167, 111, 227, 135,  50,   2,  71, 146,  69, 153, 232, 245,
	206, 192, 136, 234, 196,  86,  49,  13, 154, 162, 113,  39, 211, 101,  51,
	126, 239,  25,  28, 154,  19, 206, 133, 234, 119, 195,  17, 234,  36, 220,
	85,  33, 202, 213, 169, 191, 175,  36,  92, 139, 152, 106,   3, 212,   9,
	119,  76, 100, 251, 126, 157,   9, 218,  69, 219, 150, 158, 211,  42,  99,
	187, 114, 245, 147, 112,  83, 122, 214,   2,  51,  83, 127,  85,  16,  89,
	62,  94,  60,  61, 202,  20,  58,  36,  38, 244, 126,  93, 159, 146,  93,
	180, 101, 129, 254, 129, 107,   2,  89,  26, 219,  24,  42,   6, 188,  95,
	153, 124,  81, 202, 251,  37,   3, 249, 101, 188, 120, 114, 148, 223, 219,
	197, 212,  56, 208, 123, 240, 245, 129, 167,   3,  19,   3, 163,  42,   6,
	172,  11, 234,  36,  92,  43, 242, 105,  32, 250, 227, 161,  89,  44,  45,
	98, 196, 139,  14, 178, 146, 112,  27, 210, 179,  23, 178,   7, 203, 240,
	248, 156, 152, 251,  15,  38, 221, 146, 138, 181, 212,  73, 216,  46, 214,
	112,  11,  82, 180, 103, 138,  71, 237,  40, 145,  52,  29, 216, 221, 194,
	220,  41,  49,   0, 103,  36, 129, 185, 152, 158, 116, 101,   9, 171,  29,
	178,  85, 245, 121, 213, 235, 184,  90, 215, 229, 248,  89, 172, 112, 190,
	62,  83, 112, 209, 145,  85, 226, 229, 147, 105, 188, 142,  43, 172, 220,
	155, 179,  40,  29, 201,  85,   6, 239, 204, 153, 155, 243, 117,  47, 216,
	222, 216,  38, 229, 188, 146,  51, 188, 162, 119,  81, 194,  82, 205, 130,
	178, 189,  24, 120, 173,  97, 108,  80,  34, 102, 111,  73,  87, 182, 123,
	2, 107,   2, 231, 133, 184, 213,  89,  96,  69, 194,  56,  57,  47,  91,
	222,  57, 100, 253,  68, 130,  92, 175,  94, 148, 254, 129,  15, 240, 176,
	88,   7, 116,  39,  77, 226, 181, 187,  68, 172, 146, 154,  69,  78, 101,
	98,  77,  57,  91,  99,  81, 250,  82, 215, 138, 202, 178, 188,  44,  78,
	37,  67, 254, 196, 143, 201, 152, 141,  98, 217,  86, 224,  60,  92, 149,
	64, 207, 175,   0, 151, 178,  66, 119, 101, 249, 243,  61, 184, 163, 254,
	99, 210, 218,  48,  94,  94,   5, 101,  13, 162,   1, 176, 100, 251,  97,
	167, 249,  49, 233, 115, 179, 250, 111,  78,  23, 109, 115, 193, 178, 130,
	62,   5, 151,  20,  52,  23, 241,  76, 200,  10, 106, 149, 103, 173,  50,
	158,  21,  28,  45, 120, 174,  96, 110, 193,  71,  61, 232, 151,  61, 219,
	115,   4, 170,  82, 254, 156, 206,  16,  47, 197, 127, 231, 231, 244, 153,
	222,  27, 240, 159, 200,  63, 153, 185,  24, 191, 162, 246,  71, 153,   0,
	0,   0,   0,  73,  69,  78,  68, 174,  66,  96, 130
};

==> scummvm_2.9.1%2Bdfsg.orig.tar.xz: scummvm-2.9.1/backends/cloud/cloudicon_disabled_data.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

// This is a PNG file dumped into array.
// $ recode data..d1 <dists/cloudicon_disabled.png >cloudicon_disabled_data.h
// The tool is from https://github.com/pinard/Recode

static const byte cloudicon_disabled_data[] = {
	137,  80,  78,  71,  13,  10,  26,  10,   0,   0,   0,  13,  73,  72,  68,
	82,   0,   0,   0,  32,   0,   0,   0,  32,   8,   6,   0,   0,   0, 115,
	122, 122, 244,   0,   0,   0,   4, 115,  66,  73,  84,   8,   8,   8,   8,
	124,   8, 100, 136,   0,   0,   0,   9, 112,  72,  89, 115,   0,   0,  11,
	18,   0,   0,  11,  18,   1, 210, 221, 126, 252,   0,   0,   0,  22, 116,
	69,  88, 116,  67, 114, 101,  97, 116, 105, 111, 110,  32,  84, 105, 109,
	101,   0,  48,  54,  47,  48,  51,  47,  49,  54, 159, 192, 233, 192,   0,
	0,   0,  28, 116,  69,  88, 116,  83, 111, 102, 116, 119,  97, 114, 101,
	0,  65, 100, 111,  98, 101,  32,  70, 105, 114, 101, 119, 111, 114, 107,
	115,  32,  67,  83,  54, 232, 188, 178, 140,   0,   0,   4, 139,  73,  68,
	65,  84,  88, 133, 197, 215,  91, 168,  86,  69,  20,   7, 240, 223, 254,
	244, 120, 236, 120,  57,  26,  94,  10,  31,  34,  35,  11,  36, 203,  74,
	212, 160, 204, 212, 110, 166, 248, 208, 205, 172, 151, 144, 136, 158,  82,
	80, 168,  32, 233, 165, 160,  32, 130, 236, 165,  34, 204,  74,  18,  52,
	36, 169, 232,  34,  24, 221, 243, 218, 133,  74,  77, 195,  44, 200,  91,
	122, 188, 156, 172, 102, 159, 221, 195, 204, 246, 219, 126, 231, 226,  17,
	138,  22,  12, 123, 246, 236, 153, 245,  95, 107, 205, 127, 205, 172, 157,
	21, 254,  95, 233,  27, 122,  63, 183,   5, 179,  48,  13,  87,  98,  52,
	6, 167, 111,  71, 176,  11,  27, 177,  14, 107, 209, 222,  27, 165, 217,
	137, 211, 207,  25, 137, 197, 152, 143,  65, 189, 209, 137, 163, 120,   1,
	79,  98, 111, 143, 147, 143, 247, 172, 108,  62, 158, 194,  16,  20, 169,
	105, 232, 151,  82, 171,  24,  80,  74,  27,  22, 225, 197, 110,  13, 104,
	235, 122, 188,  31,  94, 194,  93,  21, 192,  14,  49, 172, 223, 226, 109,
	124, 130,  29, 232, 131,  49, 184,  22,  55, 166, 126,  75, 131,  65, 175,
	225,  94, 252, 213, 201, 128, 131,  93, 131, 191, 137,  27,  42, 192, 199,
	241,   6, 158, 192, 246, 238, 188,  73,  50,   6, 143,  98,  78,  50, 164,
	140, 200, 123,  34, 135,  78,  49,  34, 219, 215,  89, 193, 171, 152, 151,
	192,   3, 246, 224,   1, 188, 123,  26, 224, 170,  92, 134, 143,  49, 160,
	50,  86,  96,   5, 238, 174,  78, 108, 204, 130, 249,  98, 216,  75, 240,
	109, 184,  13,  63, 156,   1, 248,  68,  44,  21, 189,  47, 165,  67, 140,
	196,  60, 172,  87, 225,  68, 182, 167,  62, 105, 100,   2, 106,  77,  11,
	118, 139, 123, 186, 163,  59, 164,  53,  76,  16, 195, 125,  29, 250,  15,
	227, 167,  73,  12, 237,  27,  73,  91,  75, 142,  28,  21, 185,  51,  60,
	141, 181, 225,  98,  41,  59, 106,  33, 185,  26,  88,  28, 104,  77, 253,
	163, 129, 251,   3,  59,  42, 223,  79, 105, 171, 184,  53, 240,  73, 224,
	150,  64, 203,  32, 106,  99, 185, 160, 224, 236,  16, 245, 118,   4,  54,
	5, 166,   4,  22,   6, 218, 211, 218, 214, 132,  37,  32,  75, 238, 181,
	224,  55,  12,  76, 222, 191, 140, 251, 144,  39,  79, 135,  98,   1, 198,
	98,  11, 150, 227, 251,  50, 204,  67, 113, 121,  90, 156,  57, 185, 127,
	135, 154, 184,   9,  95, 160,   9,  43,  49,  59,  69, 225,  24, 206,  65,
	123, 150,  54, 247,  14, 188, 158, 214,  30,  23,  79, 186, 109,   9, 252,
	44, 124, 142, 113, 149, 232, 127, 134, 201, 196,  88,  79,  66, 115,   5,
	252,  24, 182, 114, 224,  32,  35, 230, 212, 207, 139,  75, 241, 169, 168,
	47, 195, 157,  88,  89, 110, 193, 180,  64, 145, 250, 223,   5, 182,  87,
	194, 125, 123,  96,  92, 195,  22,  76,  14, 201, 227, 177, 226,  65, 144,
	227, 111,  28, 198, 151, 113, 131, 135,   5,  46, 169, 172, 249,  38, 176,
	187, 242,  62,  35, 160, 150, 199, 197,  19, 114, 178, 156,  34, 231, 173,
	244, 180, 154, 115, 115, 166, 166,  57, 167, 180, 193,  34,   3,   7, 165,
	61,  11, 137, 105,  27, 112, 160,  62, 111, 235, 106,  22, 166, 126,  71,
	206,  59, 165, 238, 156,  43, 114, 100, 155,  98, 120, 218, 146, 206,   2,
	83, 241, 225,  26, 134, 165, 253,  27, 173,  65, 134, 138, 137, 222, 154,
	222, 139, 228, 249,  87, 233, 217, 133,  76, 159,  19,  47, 169,  89, 226,
	129, 214,  71, 188, 192, 134, 148, 231,  64, 121, 171,  21, 248,  85, 244,
	232, 177,  30, 192,  59,  90,  82,   6, 193,   9, 108, 234,  30,  28,  30,
	9, 209, 128,  74, 214,  71, 204, 190, 121, 231, 201,   5, 228, 220, 218,
	248,  97, 136, 200, 246, 102, 106,  29, 234,  73, 190,   5, 135, 186,   7,
	135, 201,   9, 167, 111, 227, 135,  50,   2,  71, 146,  69, 153, 232, 245,
	206, 192, 136, 234, 196,  86,  49,  13, 154, 162, 113,  39, 211, 101,  51,
	126, 239,  25,  28, 154,  19, 206, 133, 234, 119, 195,  17, 234,  36, 220,
	85,  33, 202, 213, 169, 191, 175,  36,  92, 139, 152, 106,   3, 212,   9,
	119,  76, 100, 251, 126, 157,   9, 218,  69, 219, 150, 158, 211,  42,  99,
	187, 114, 245, 147, 112,  83, 122, 214,   2,  51,  83, 127,  85,  16,  89,
	62,  94,  60,  61, 202,  20,  58,  36,  38, 244, 126,  93, 159, 146,  93,
	180, 101, 129, 254, 129, 107,   2,  89,  26, 219,  24,  42,   6, 188,  95,
	153, 124,  81, 202, 251,  37,   3, 249, 101, 188, 120, 114, 148, 223, 219,
	197, 212,  56, 208, 123, 240, 245, 129, 167,   3,  19,   3, 163,  42,   6,
	172,  11, 234,  36,  92,  43, 242, 105,  32, 250, 227, 161,  89,  44,  45,
	98, 196, 139,  14, 178, 146, 112,  27, 210, 179,  23, 178,   7, 203, 240,
	248, 156, 152, 251,  15,  38, 221, 146, 138, 181, 212,  73, 216,  46, 214,
	112,  11,  82, 180, 103, 138,  71, 237,  40, 145,  52,  29, 216, 221, 194,
	220,  41,  49,   0, 103,  36, 129, 185, 152, 158, 116, 101,   9, 171,  29,
	178,  85, 245, 121, 213, 235, 184,  90, 215, 229, 248,  89, 172, 112, 190,
	62,  83, 112, 209, 145,  85, 226, 229, 147, 105, 188, 142,  43, 172, 220,
	155, 179,  40,  29, 201,  85,   6, 239, 204, 153, 155, 243, 117,  47, 216,
	222, 216,  38, 229, 188, 146,  51, 188, 162, 119,  81, 194,  82, 205, 130,
	178, 189,  24, 120, 173,  97, 108,  80,  34, 102, 111,  73,  87, 182, 123,
	2, 107,   2, 231, 133, 184, 213,  89,  96,  69, 194,  56,  57,  47,  91,
	222,  57, 100, 253,  68, 130,  92, 175,  94, 148, 254, 129,  15, 240, 176,
	88,   7, 116,  39,  77, 226, 181, 187,  68, 172, 146, 154,  69,  78, 101,
	98,  77,  57,  91,  99,  81, 250,  82, 215, 138, 202, 178, 188,  44,  78,
	37,  67, 254, 196, 143, 201, 152, 141,  98, 217,  86, 224,  60,  92, 149,
	64, 207, 175,   0, 151, 178,  66, 119, 101, 249, 243,  61, 184, 163, 254,
	99, 210, 218,  48,  94,  94,   5, 101,  13, 162,   1, 176, 100, 251,  97,
	167, 249,  49, 233, 115, 179, 250, 111,  78,  23, 109, 115, 193, 178, 130,
	62,   5, 151,  20,  52,  23, 241,  76, 200,  10, 106, 149, 103, 173,  50,
	158,  21,  28,  45, 120, 174,  96, 110, 193,  71,  61, 232, 151,  61, 219,
	115,   4, 170,  82, 254, 156, 206,  16,  47, 197, 127, 231, 231, 244, 153,
	222,  27, 240, 159, 200,  63, 153, 185,  24, 191, 162, 246,  71, 153,   0,
	0,   0,   0,  73,  69,  78,  68, 174,  66,  96, 130
};
